ELATE: Elastic tensor analysis
=====

Welcome to [ELATE, the online tool for analysis of elastic tensors](http://progs.coudert.name/elate), developped and maintained by [François-Xavier Coudert](http://coudert.name) at CNRS / Chimie ParisTech.

This repository contains the source code for the web service, which you can use [online here](http://progs.coudert.name/elate).

If you use the software (the website or the code itself) in published results (paper, conference, etc.), please cite the [corresponding paper (_J. Phys. Condens. Matter_, *2016*, 28, 275201)](https://doi.org/10.1088/0953-8984/28/27/275201).
